@@ -1,5 +1,6 @@
 """The supermodels package."""
 
+from supermodels.fields import masked_field, timestamp_field, uuid_field, version_field
 from supermodels.models import (
     from_dict,
     from_json,
@@ -15,8 +16,12 @@ __all__ = [
     "from_dict",
     "from_json",
     "is_supermodel",
+    "masked_field",
     "NewRules",
     "to_dict",
     "to_json",
     "supermodel",
+    "timestamp_field",
+    "uuid_field",
+    "version_field",
 ]
