@@ -30,3 +30,9 @@ class ValidationError(SupermodelsException):
     """Provides a custom validation error class."""
 
     pass
+
+
+class ImmutableFieldError(SupermodelsException):
+    """Provides a custom frozen field error class."""
+
+    pass
