@@ -241,8 +241,6 @@ def from_json(cls, payload: str):
 
 def to_dict(self, repr_only: Optional[bool] = False) -> str:
     """Returns a dictionary with model attributes and values."""
-    items = asdict(self)
-
     ignored_field_names = [
         own_field.name
         for own_field in fields(self)
@@ -253,7 +251,8 @@ def to_dict(self, repr_only: Optional[bool] = False) -> str:
 
     data = {}
 
-    for key in items:
+    for own_field in fields(self):
+        key = own_field.name
         if key in ignored_field_names:
             continue
 
@@ -276,7 +275,7 @@ def to_dict(self, repr_only: Optional[bool] = False) -> str:
                 data[key] = type(value)(iterable)
                 continue
 
-        data[key] = items[key]
+        data[key] = value
 
     return data
 
