@@ -6,6 +6,7 @@ from collections import deque
 from dataclasses import dataclass, Field, is_dataclass
 from datetime import datetime
 from enum import EnumMeta
+from types import FunctionType, GeneratorType
 from uuid import UUID
 from typing import Any, Callable, get_args, Pattern, Type
 
@@ -43,6 +44,8 @@ class DataModelSerializer(json.JSONEncoder):
         re.Pattern: lambda x: x.pattern,
         set: list,
         UUID: str,
+        GeneratorType: lambda x: str(x),
+        FunctionType: lambda x: x.__name__,
     }
 
     @classmethod
